#ifndef NT2_INCLUDE_FUNCTIONS_COSD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COSD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cosd.hpp>

#endif
